@@ -8,6 +8,8 @@
 #'    samples when \code{sam.out$num.sam} is greater than one. When \code{num.sam} is an
 #'    integer, N, LSMI from 1 to N are taken from the input \code{sam.out}.
 #' @param n.boot A positive integer number, the number of bootstrap replications.
+#' @param method Can be either "w" for weighted bootstrap or "nw" for
+#'    non-weighted bootstrap. "w" is recommended and set as the default method.
 #' @references Efron, B. (1979). Bootstrap methods: another look at the
 #'  jackknife. The annals of Statistics, 1-26.
 #' @references Thompson, M. E., Ramirez Ramirez, L. L., Lyubchich, V. and
@@ -16,13 +18,16 @@
 #' @return A list consisting of:
 #'    \item{values}{A list of length \code{num.sam} where each element is a
 #'          vector containing the unique degree values sampled in each LSMI.}
-#'    \item{empd}{A list of length three where each element contains a different
-#'          estimate of degree distribution: empd.w.p0s - weighted bootstrap
-#'          with a proportion of isolated nodes p0 being estimated by simple
-#'          random sampling of bootstrapped seeds; empd.nw.p0sEkb - non-weighted
-#'          bootstrap with a proportion of isolated nodes p0 being estimated by
-#'          simple random sampling of bootstrapped seeds; empd.nw.p0sEks -ignore
-#'          (see Thompson et al. for details)}
+#'    \item{empd}{A list of length \code{num.sam} where each element contains an
+#'          estimate of degree distribution for each LSMI. The method of
+#'          estimation is set with the \code{method} parameter. If
+#'          \code{method="w"} the object empd.w.p0s is returned, which is
+#'          a weighted bootstrap with a proportion of isolated nodes, p0,
+#'          being estimated by simple random sampling of bootstrapped
+#'          seeds; If \code{method="nw"} the object empd.nw.p0sEkb, which
+#'          is - non-weighted bootstrap with a proportion of isolated nodes,
+#'          p0, being estimated by simple random sampling of bootstrapped seeds
+#'          (see Thompson et al. for details).}
 #'    \item{num.sam}{Numeric indices corresponding to LSMI samples used for bootstrap.}
 #'    \item{n.boot}{The same object as input argument \code{n.boot}.}
 #'    \item{n.neigh}{The number of waves carried out by the snowball sample.
@@ -41,12 +46,12 @@
 #' sam.out <- Oempdegreedistrib(net = net, n.seeds = 40, n.neigh = 1, num.sam = 1)
 #' a <- bootdeg(sam.out = sam.out, n.boot = 50)
 
-bootdeg <- function(sam.out, num.sam = sam.out$num.sam, n.boot = 1) {
+bootdeg <- function(sam.out, num.sam = sam.out$num.sam, n.boot = 1, method = "w") {
       if (sam.out$n.neigh == 0) {
             # only information from the seeds
             res <- bootdeg0(sam.out, num.sam, n.boot)
       } else {
-            res <- bootdegK(sam.out, num.sam, n.boot)
+            res <- bootdegK(sam.out, num.sam, n.boot, method = "w")
       }
       res
 }
